@@ -4,7 +4,7 @@
 
 asImRaster = function(X, ...) {
 
-if(any(rownames(installed.packages())=='spatstat')){	
+if(all(c('spatstat','mgcv') %in% rownames(installed.packages()))){	
 	res=spatstat::as.im(raster::as.matrix(X)[nrow(X):1,], 
 			xrange=bbox(X)[1,], 
 			yrange=bbox(X)[2,], ...)
