@@ -91,7 +91,7 @@ swissSim = RFsimulate(
 
 swissSim = RFsimulate(
 		model=swissRes$param,
-		data=swissRes$data['resid'],
+		data=swissRes$data[,'resid'],
 		x=swissRes$predict,
 		err.model=swissRes$param["nugget"],
 		n=3
@@ -106,7 +106,7 @@ swissSim = RFsimulate(model=
 				rbind(
 						swissRes$param,
 						swissRes$param*0.99),
-		data=swissRes$data['resid'],
+		data=swissRes$data[,'resid'],
 		x=swissRes$predict,
 		err.model=c(1, 0.99)*swissRes$param["nugget"],
 		n=3
@@ -122,7 +122,7 @@ swissSim = RFsimulate(model=
 						swissRes$param,	
 						0.99*swissRes$param,
 						1.01*swissRes$param),
-		data=swissRes$data['resid'][,c(1,1,1)],
+		data=swissRes$data[,rep('resid',3)],
 		err.model=c(1, 0.99, 1.01)*swissRes$param["nugget"],
 		x=swissRes$predict,
 		n=3
