@@ -18,7 +18,8 @@ trueParamAniso = param=c(variance=2^2, range=0.2, shape=2,
 
 
 
-mydat$U = geostatsp::RFsimulate(trueParamAniso,mydat)$variable1
+mydat$U = RFsimulate(trueParamAniso,mydat)$sim1
+
 mydat$Y = -3 + 0.5*mydat$cov1 + 0.2*mydat$cov2 + 
 		mydat$U + rnorm(length(mydat), 0, sd=sqrt(trueParamAniso["nugget"]))
 
@@ -73,7 +74,7 @@ mydat = SpatialPointsDataFrame(cbind(runif(n), runif(n)),
 # simulate a random field
 trueParam = c(variance=2^2, range=0.15, shape=2, nugget=0.5^2)
 
-mydat$U = geostatsp::RFsimulate(trueParam,mydat)$variable1
+mydat$U = geostatsp::RFsimulate(trueParam,mydat)$sim1
 
 # add fixed effects
 mydat$Y = -3 + 0.5*mydat$cov1 + 0.2*mydat$cov2 + 
